smstools - universal phone sms converter
========================================

Multipurpose import / export / merge tool for your text message history.

Go to the `github page for SMS-Tools`__ for documentation, wiki, issues, etc.

__ https://github.com/t413/SMS-Tools


--------------

Howto:
------

``pip install smstools`` (requires *unicodecsv* package)

``smstools <in> <out>`` (It'll be in your path)

::

    usage: smstools[-h] [--type {xml,json,android,csv,ios5,ios7,ios6}]
                        infiles [infiles ...] outfile

